import React, { useEffect } from "react";
import './App.css';
import {
  Redirect,
  Route,
  BrowserRouter as Router,
  Switch,
} from 'react-router-dom';
import { ThemeProvider } from "@material-ui/core/styles"
import { CssBaseline } from "@material-ui/core";
import { theme } from "./style/Theme";
import { IOCListView } from './views/IOC/IOCListView';
import { HomeAccessControl } from './views/home/HomeAccessControl';
import { GlobalAppBar } from './components/navigation/GlobalAppBar/GlobalAppBar';
import { IOCDetailsAccessControl } from './views/IOC/IOCDetailsAccessControl';
import { DeploymentsAccessControl } from './views/deployments/DeploymentsAccessControl'
import { DeploymentDetailsAccessControl } from './views/deployments/DeploymentDetailsAccessControl'
import { APIProvider, UserProvider } from './api/SwaggerApi';
import { HostListView } from "./views/host/HostListView";
import { HostDetailsAccessControl } from "./views/host/HostDetailsAccessControl";
import { StatisticsView } from "./views/statistics/StatisticsView";
import { HelpView } from "./views/help/HelpView";
import { AboutView } from "./views/about/AboutView";
import { SnackbarProvider } from 'notistack';
import TokenRenew from './components/auth/TokenRenew';
import {NotificationProvider} from './components/common/notification/Notifications';
import NotFound from './components/navigation/NotFound';
import { applicationSubTitle } from './components/common/Helper';

//setting up the application (TAB)title
function App() {
  useEffect(() => {
    document.title = "CCCE" + applicationSubTitle();
 }, []);

  return (
    <SnackbarProvider preventDuplicate maxSnack="5">
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <Router>
          <APIProvider >
            <UserProvider>
              <TokenRenew />
              <Switch>
                <Route path="/"
                  render={({ match }) => {
                    console.log(match)
                    return (
                        <NotificationProvider>
                          <GlobalAppBar>
                            <Switch>
                              <Route exact path="/">
                                <Redirect to="/home" />
                              </Route>
                              <Route path="/home" component={HomeAccessControl} />
                              <Route path="/iocs/:id" component={IOCDetailsAccessControl} />
                              <Route path="/iocs" component={IOCListView} />
                              <Route path="/deployments/:id" component={DeploymentDetailsAccessControl} />
                              <Route path="/deployments" component={DeploymentsAccessControl} />
                              <Route path="/hosts/:id" component={HostDetailsAccessControl} />
                              <Route path="/hosts" component={HostListView} />
                              <Route path="/statistics" component={StatisticsView} />
                              <Route path="/help" component={HelpView} />
                              <Route path="/about" component={AboutView} />
                              <Route>
                                <NotFound />
                              </Route>
                            </Switch>
                          </GlobalAppBar>
                        </NotificationProvider>
                    )
                  }
                  }
                />
                <Route>
                  <NotFound />
                </Route>
              </Switch>
            </UserProvider>
          </APIProvider>
        </Router>
      </ThemeProvider>
    </SnackbarProvider>
  );
}

export default App;
