import React, { useState, useEffect } from "react";
import moment from 'moment';
import { alpha } from '@material-ui/core/styles/colorManipulator';


export function formatToList(items) {

    if(!items) return null;

    return (
        <ul style={{ padding: 0 }}>
            {items.map((item) => (
                <li style={{ listStylePosition: 'inside' }} key={item}>{item}</li>
            ))}
        </ul>
    )
}

export function searchInArray(array, searchText) {
    if(array) {
        const found = array.find(element => element.toLowerCase().includes(searchText) );

        return found;
    }

    return false;
}

export const formatDate = (value) => {
    if (value) {
      return moment(value).format('DD/MM/YYYY HH:mm:ss');
    }
    return null;
}

export const formatDateOnly = (value) => {
  if (value) {
    return moment(value).format(dateFormat);
  }
  return null;
}

export const dateFormat = () => {
  return 'DD/MM/YYYY';
}

function getWindowDimensions() {
  const { innerWidth: width, innerHeight: height } = window;
  return {
    width,
    height
  };
}

export function useWindowDimensions() {
  const [windowDimensions, setWindowDimensions] = useState(getWindowDimensions());

  useEffect(() => {
    function handleResize() {
      setWindowDimensions(getWindowDimensions());
    }

    window.addEventListener('resize', handleResize);
    return () => window.removeEventListener('resize', handleResize);
  }, []);

  return windowDimensions;
} 

export function circularPalette(palette, index, opacity=1.0) {
  const colors = Object.values(palette);
  let n = colors.length;
  return alpha(colors[(index % n + n) % n], opacity);
}

export function applicationSubTitle() {
  const title = `${window.ENVIRONMENT_TITLE}`;

  if((title) && (title !== 'undefined')) {
    return ' - ' + title;
  }

  return '';
}

export function initRequestParams(lazyParams, filter, columnSort) {
  let requestParams = {
    page: lazyParams.page, 
    limit: lazyParams.rows
  }
  if ((filter != null) && filter) {
    requestParams.query = filter;
  }

  if(columnSort) {
    if(columnSort.sortOrder === 1) {
      requestParams.isAsc = true;
    } else {
      requestParams.isAsc = false;
    }
  }

  return requestParams;
}
