import React, { useState, useEffect } from 'react';
import { LinearProgress, Typography, Container } from '@material-ui/core';
import { useDeploymentJob } from '../../api/SwaggerApi';
import { Console } from "../common/Console/Console";
import { Alert } from "@material-ui/lab";

export function DeploymentJobOutput({ awxJobId, update }) {
  const [error, setError] = useState();

  function onError(message) {
    setError(message);
  }  

  const [deploymentJob, getDeploymentJob] = useDeploymentJob(awxJobId, onError);
  const [oneMoreIteration, setOneMoreIteration] = useState(true);

  useEffect(() => {
    const interval = setInterval(() => {
      if (update) {
        getDeploymentJob();
      }

      if(!update && oneMoreIteration) {
        getDeploymentJob();
        setOneMoreIteration(false);
      }
    }, 5000);
    return () => clearInterval(interval);
  }, [update, oneMoreIteration, getDeploymentJob]);

  const dataReady = () => {
    return deploymentJob?.started;
  }

  let header = (
    <div style={{
      display: "flex",
      alignItems: "center"
    }}>
      <Typography variant="overline">DURATION: </Typography>
      <Typography style={{
          marginLeft: "6px",
        }}>
        {deploymentJob?.elapsed.toFixed(0)} s
      </Typography>
    </div>
  );

  return(
    <Container maxWidth='xl'>
      {error ?
        <Alert severity="error">{error}</Alert>
        :
        deploymentJob?.started ?
          <div style={{
              width: "100%",
            }}>
            <Console 
              html={deploymentJob.stdout}
              dataReady={dataReady}
              title="AWX job details"
              dialogHeader={header}
            />
          </div>
          : 
          <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>
      }
    </Container>
    )
}