import React from 'react';
import { Grid, Tooltip } from "@material-ui/core";
import { CustomTable } from '../common/table/CustomTable';
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { useHistory } from 'react-router-dom';
import { HostStatusIcon } from './HostIcons';

const columns = [
    { id: 'bulb', label: 'Status', width: '6%' },
    { id: 'host', label: 'Host', width: '24%' },
    { id: 'description', label: 'Description', width: '28%' },
    { id: 'network', label: 'Network', width: '15%' },
    { id: 'scope', label: 'Scope', width: '15%' },
    { id: 'deviceType', label: 'Device Type', width: '12%' },
];

export function rowDescription(description) {

    return(
        <div className={'shortenLongDataLines'}>
            <Tooltip title={description} arrow enterDelay={400}>
                <label>{description}</label>
            </Tooltip>
        </div>
    );
}

export function createRow(hostContainer) {
    const host = hostContainer.csEntryHost;
    return {
        id: host.id,
        bulb: 
          <Grid container direction="column" justifyContent="center" alignItems="center">
            <HostStatusIcon host={hostContainer} />
          </Grid>,
        host: host.name,
        description: rowDescription(host.description),
        network: host.network,
        deviceType: host.deviceType,
        scope: host.scope,
        shortenLongData: true,
    };

}

export function HostsTable({ hosts, totalCount, lazyParams, setLazyParams, columnSort, setColumnSort, rowsPerPage}) {
    const history = useHistory();

    console.log(hosts);

    const onRowClicked = (id) => {
        history.push(`/hosts/${id}`);
    };

    return <CustomTable columns={columns} rows={hosts.map(host => createRow(host))} handleRowClick={onRowClicked} totalCount={totalCount}
        lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} rowsPerPage={rowsPerPage}/>;
}

export default function HostTable({ hosts, setQuery, totalCount, lazyParams, setLazyParams, columnSort, setColumnSort, rowsPerPage}) {
    const filter = (search) => {
        setQuery(search.toLowerCase());
        return (hostContainer) => {
            return true;    
        }
    }

    const renderFilteredHosts = (filteredHosts) => <HostsTable hosts={filteredHosts} totalCount={totalCount} 
        lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} rowsPerPage={rowsPerPage}/>;

    return (
        <SearchBoxFilter items={hosts} filter={filter} render={renderFilteredHosts} />
    );
}