import React, { useState } from 'react';
import { useCurrentlyActiveIOCs } from '../../api/SwaggerApi';
import { useEffect, useRef } from 'react';
import { LinearProgress, useTheme } from '@material-ui/core';
import { Bar } from 'react-chartjs-2';
import ChartDataLabels from 'chartjs-plugin-datalabels';
import { circularPalette } from '../common/Helper';

export default function ActiveIOCChart() {

    const [activeIocs, getActiveIocs] = useCurrentlyActiveIOCs();
    const activeIocChartRef = useRef(null);
    const [chartData, setChartData] = useState({});
    const theme = useTheme();

    useEffect(() => {
        getActiveIocs();
    }, [getActiveIocs]
    );

    useEffect(() => {

        const chart = () => {
            let barData = [];
            let brdColor = [];

            Object.values(activeIocs).forEach((ioc, index) => {
                barData.push(ioc);
                brdColor.push(circularPalette(theme.palette.graph, index));

            });//Object.foreach

            setChartData({
                datasets: [
                    {
                        parsing: {
                            xAxisKey: 'network',
                            yAxisKey: 'iocCount'
                        },
                        data: barData,
                        backgroundColor: brdColor
                    }
                ]
            });

        }

        if ((activeIocs)) {
            chart();
        }
    }, [activeIocs]
    );

    let basicOptions = {
        aspectRatio: 5 / 3,
        maintainAspectRatio: true,
        layout: {
            padding: {
                top: 32,
                right: 16,
                bottom: 16,
                left: 8
            }
        },
        plugins: {
            datalabels: {
                backgroundColor: function (context) {
                    return context.dataset.backgroundColor;
                },
                formatter: function (value, context) {
                    return value.iocCount;
                },
                borderRadius: 3,
                color: 'white',
                font: {
                    weight: 'bold'
                },
                padding: {
                    top: 4,
                    bottom: 4,
                    left: 4,
                    right: 4
                },
                align: 'top',
                anchor: 'end',
                offset: 10,
                clip: true
            },
            legend: {
                display: false,
                labels: {
                    color: '#495057'
                },
                position: 'right'
            },
            title: {
                display: true,
                font: {
                    size: 16
                },
                text: 'Statistics about currently active IOCs according to Prometheus'
            },
            tooltip: {
                position: 'nearest',
                mode: 'point'
            }
        },
        scales: {
            x: {
                ticks: {
                    color: '#495057',
                    display: true
                },
                grid: {
                    color: '#ebedef'
                }
            },
            y: {
                ticks: {
                    color: '#495057'
                },
                grid: {
                    color: '#ebedef'
                }
            }
        }
    };


    return (
        <>
            {
                activeIocs ?
                    <div>
                        <Bar data={chartData} options={basicOptions} ref={activeIocChartRef} plugins={[ChartDataLabels]} />
                    </div>
                    :
                    <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>
            }
        </>
    );

}