import React from 'react';
import { useEffect, useRef } from 'react';
import { dateFormat } from '../common/Helper';
import { LinearProgress, Button, useTheme } from '@material-ui/core';
import zoomPlugin from "chartjs-plugin-zoom";
import { Line, Chart } from 'react-chartjs-2';
import 'chartjs-adapter-moment';
import { circularPalette } from '../common/Helper';

Chart.register(zoomPlugin); // REGISTER PLUGIN

export default function DeploymentLineChart({title, chartLabel, hook}) {

    const [iocDeployments, getIOCDeployments] = hook();
    const theme = useTheme();

    useEffect(() => {
        getIOCDeployments();
    }, [getIOCDeployments]
    );

    let basicOptions = {
        aspectRatio: 5 / 3,
        layout: {
            padding: {
                top: 32,
                right: 16,
                bottom: 16,
                left: 8
            }
        },
        parsing: {
            xAxisKey: 'historyDate',
            yAxisKey: 'iocCount'
        },
        plugins: {
            zoom: {
                pan: {
                    enabled: true,
                    mode: 'xy',
                    threshold: 0
                },
                zoom: {
                    wheel: {
                        modifierKey: 'ctrl',
                        enabled: true
                    },
                    pinch: {
                        enabled: true
                    },
                    enabled: true,
                    mode: 'xy'
                }
            },
            legend: {
                labels: {
                    color: '#495057'
                }
            },
            title: {
                display: true,
                font: {
                    size: 16
                },
                text: title
            }
        },
        scales: {
            x: {
                type: 'time',
                time: {
                    unit: "day",
                    displayFormats: {
                        day: dateFormat
                    },
                    tooltipFormat: dateFormat,
                },
                ticks: {
                    color: '#495057'
                },
                grid: {
                    color: '#ebedef'
                }
            },
            y: {
                ticks: {
                    color: '#495057',
                    stepSize: 1
                },
                grid: {
                    color: '#ebedef'
                }
            }
        }
    };

    const iocChartRef = useRef(null);

    const resetIocZoom = () => {
        iocChartRef.current.resetZoom()
    }

    useEffect(() => {
        if ((iocChartRef.current) && (iocDeployments)) {

            let iocColor = circularPalette(theme.palette.graph, 0);
            let fillColor = circularPalette(theme.palette.graph, 0, 0.2);
            iocChartRef.current.data.datasets.push({
                label: chartLabel,
                fill: true,
                backgroundColor: fillColor,
                borderColor: iocColor,
                tension: 0,
                parsing: {
                    xAxisKey: 'historyDate',
                    yAxisKey: 'iocCount'
                },
                data: Object.values(iocDeployments)
            });
            iocChartRef.current.update();
        }
    }
    );


    return (
        <>
            {
                iocDeployments ?
                    <div>
                        <Button onClick={resetIocZoom} variant="contained">RESET VIEW</Button>
                        <Line options={basicOptions} ref={iocChartRef} />
                    </div>
                    :
                    <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>
            }
        </>

    );
}
