import { Grid, Paper, Tab, Tabs, Typography, IconButton } from "@material-ui/core";
import ArrowBackIcon from '@material-ui/icons/ArrowBack';
import React, { useEffect, useState } from "react";
import { useCommandList } from "../../api/SwaggerApi";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCManage } from "../../components/IOC/IOCManage";
import { useHistory } from "react-router-dom";
import IOCAdmin from "../../components/IOC/IOCAdmin";
import AccessControl from "../../components/auth/AccessControl";
import { initRequestParams } from "../../components/common/Helper";

export function IOCDetailsView({ ioc, getIOC }) {
  console.log(ioc);
  const [selectedTab, setSelectedTab] = useState("Manage deployment");
  const [firstTime, setFirstTime] = useState(true);
  const [buttonDisabled, setButtonDisabled] = useState(false);
  const history = useHistory();
  const [commands, getCommands] = useCommandList();
  const [ongoingCommand, setOngoingCommand] = useState(null);
  const [operationQueued, setOperationQueued] = useState(false);

  const [commandLazyParams, setCommandLazyParams] = useState({
    first: 0,
    rows: 5,
    page: 0
  });
  
  const [commandColumnSort, setCommandColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  const rowsPerPage = [5, 10, 20, 50];

  useEffect(() => {
    if (commands && commands.length > 0 && !["successful", "failed"].includes(commands[0].status?.toLowerCase())) {
      setOngoingCommand(commands[0]);
      setOperationQueued(false);
    } else {
      setOngoingCommand(null);
    }
  }, [commands, setOngoingCommand]);

  useEffect(() => {
    if (operationQueued) {
      setButtonDisabled(true);
    } 
  }, [operationQueued, setButtonDisabled]);

  useEffect(() => {
    const interval = setInterval(() => {
      if (ongoingCommand) {
        getCommands();
        setOperationQueued(false);
        setButtonDisabled(true);
      } else {
        setButtonDisabled(operationQueued);
      }
    }, 2000);
    return () => clearInterval(interval);
  }, [ongoingCommand, operationQueued, getCommands, setButtonDisabled]);

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  useEffect(() => {
    const interval = setInterval(() => {
        getIOC();
    }, 10000);
    return () => clearInterval(interval);
  }, [getIOC]);

  useEffect(() => {
    if (firstTime && ioc && ioc.activeDeployment) {
      setSelectedTab("Live Status");
      setFirstTime(false);
    }
  }, [ioc, firstTime]);

  useEffect(() => {
    let requestParams = initRequestParams(commandLazyParams, null, commandColumnSort);

    requestParams.deploymentId = ioc.activeDeployment?.id;

    getCommands(requestParams);

  }, [getCommands, commandLazyParams, commandColumnSort, ioc])

  const handleClick = () => {
    history.goBack();
  };

  function resetTab() {
    if (ioc && ioc.activeDeployment) {
      setSelectedTab("Live Status");
    } else {
      setSelectedTab("Manage deployment");
    }
  }

  return (
    <Paper>
      <Grid container spacing={1}>
        <Grid item xs={1}>
          <IconButton color="inherit" onClick={handleClick}>
            <ArrowBackIcon />
          </IconButton>
        </Grid>
        <Grid item xs={11}>
          <Grid container justify="center">
            <AccessControl 
              allowedRoles={["DeploymentToolAdmin"]}
              allowedUsersWithRoles={[{user: ioc.owner, role: "DeploymentToolIntegrator"}]}
              renderNoAccess={() =>
                <Tabs
                  value={selectedTab}
                  onChange={handleTabChange}
                  indicatorColor="primary"
                  textColor="primary"
                >
                  {ioc && ioc.activeDeployment && <Tab label={<Typography variant="h5">Live Status</Typography>} value="Live Status" />}
                  {ioc && <Tab label={<Typography variant="h5">Manage deployment</Typography>} value="Manage deployment" />}
                </Tabs>
              }>
                
              <Tabs
                value={selectedTab}
                onChange={handleTabChange}
                indicatorColor="primary"
                textColor="primary"
              >
                {ioc && ioc.activeDeployment && <Tab label={<Typography variant="h5">Live Status</Typography>} value="Live Status" />}
                {ioc && <Tab label={<Typography variant="h5">Manage deployment</Typography>} value="Manage deployment" />}
                {ioc && <Tab label={<Typography variant="h5">IOC Admin</Typography>} value="IOC Admin" />}
              </Tabs>
            </AccessControl>
          </Grid>
        </Grid>
        <Grid item xs={12} style={{ paddingBottom: 0 }}>
          {selectedTab === "Live Status" && <IOCLiveStatus ioc={ioc} getIOC={getIOC} ongoingCommand={ongoingCommand} commands={commands} getCommands={getCommands}
              buttonDisabled={buttonDisabled} setOperationQueued={setOperationQueued} 
              commandLazyParams={commandLazyParams} setCommandLazyParams={setCommandLazyParams} commandColumnSort={commandColumnSort} setCommandColumnSort={setCommandColumnSort} 
              rowsPerPage={rowsPerPage}/>}
          {selectedTab === "Manage deployment" && <IOCManage ioc={ioc} getIOC={getIOC} buttonDisabled={buttonDisabled} />}
          {selectedTab === "IOC Admin" && <IOCAdmin ioc={ioc} getIOC={getIOC} resetTab={resetTab} buttonDisabled={buttonDisabled}/>}
        </Grid>
      </Grid>
    </Paper>
  );
}