import { Container, Grid, Hidden, Paper } from "@material-ui/core";
import { RootContainer } from "../../components/common/Container/RootContainer";
import React, { useState, useEffect } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { SearchableIOCList } from "../../components/IOC/IOCList";
import { SearchableIOCTable } from "../../components/IOC/IOCTable";
import { useIOCSearch } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function IOCListView() {
  const [iocs, getIocs] = useIOCSearch();
  const [query, setQuery] = useState();
  const classes = useStyles();

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 20,
    page: 0
  });
  
  const [columnSort, setColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  const rowsPerPage = [5, 10, 20, 50, 100];

  
  console.log("rendering Explore IOCs")

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams, query, columnSort);

    if(columnSort.sortField === "owner") {
      requestParams.orderBy = "OWNER";
    }
  
    if(columnSort.sortField === "namingName") {
      requestParams.orderBy = "IOC_NAME";
    }
  
    if(columnSort.sortField === "sourceVersion") {
      requestParams.orderBy = "GIT_REFERENCE";
    }

    getIocs(requestParams);

  }, [getIocs, lazyParams, columnSort, query])

  const title = "Explore IOCs";
  useGlobalAppBar(title);

  let content = (
    <>
      <Hidden smUp>
        <SearchableIOCList iocs={iocs.iocList} setQuery={setQuery}/>
      </Hidden>
      <Hidden xsDown>
        <SearchableIOCTable iocs={iocs.iocList} setQuery={setQuery} rowType="explore" 
          lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort} totalCount={iocs.totalCount} 
          rowsPerPage={rowsPerPage} />
      </Hidden>
    </>
  );

  return (
    <RootContainer>
      <Container>
        <Paper className={classes.root}>
          <Grid container spacing={1}>
            <Grid item xs={12}>
              {content}
            </Grid>
          </Grid>
        </Paper>
      </Container>
    </RootContainer>
  );
}

