import React from "react";
import {
  Paper,
  Link,
  Typography,
  makeStyles
} from "@material-ui/core";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import './helpfile.css';
import { RootContainer } from "../../components/common/Container/RootContainer";

const useStyles = makeStyles((theme) => ({
  paper: {
    maxWidth: "80%",
    padding: theme.spacing(4),
  },
}));

export function HelpView() {
  const classes = useStyles();
  const title = "Help";
  useGlobalAppBar(title);

  return (
    <RootContainer>
      <h2>Help</h2>
      <Paper className={classes.paper}>
        <Typography variant="body1">
          <p>Before you can deploy an IOC, <b>you need to</b>:
            <ul>
              <li>register the IOC in <Link href="https://ccdb.esss.lu.se/" target="_blank" rel="noreferrer">CCDB</Link> (go <Link href="https://confluence.esss.lu.se/x/k41nFg" target="_blank" rel="noreferrer">here</Link> for help),</li>
              <li>have your IOC in a ESS Gitlab repository in the <Link href="https://gitlab.esss.lu.se/iocs" target="_blank" rel="noreferrer">IOCs</Link> group (you can use <Link href="https://gitlab.esss.lu.se/ics-cookiecutter/cookiecutter-e3-ioc" target="_blank" rel="noreferrer">cookiecutter</Link> to create the repository, or you can create it by hand - you can find an example IOC repository <Link href="https://gitlab.esss.lu.se/ccce/dev/e3-ioc-ccce-example" target="_blank" rel="noreferrer">here</Link>), </li>
              <li>and you need an IOC host registered in <Link href="https://csentry.esss.lu.se/" target="_blank" rel="noreferrer">CSEntry</Link> (physical or virtual).</li>
            </ul>
            Deployments shall be done on blank (formatted) machines set up with CSEntry - some configuration is done during OS installation. Deployments made on old hosts, or hosts which make use mixed deployment methods (e.g. with both manually and CCCE-deployed IOCs) are not supported by the CCCE team.
            
            Note that we currently only support deployments on CentOS 7.</p>

          <hr />

          <p>If you need support, please visit the <Link href="https://ess-eric.slack.com/archives/C01V3R31EP2" target="_blank" rel="noreferrer">#ccce-ioc-deployment-beta</Link> channel on ESS&lsquo; Slack.</p>

          <p>We also have a bug tracker and Known Issues page on <Link href="https://confluence.esss.lu.se/x/3fPIFQ" target="_blank" rel="noreferrer">Confluence.</Link>, as well as a number of help articles (for example on how to migrate existing autosave filse or for how to locate local log-files) under the parent-page.</p>
        </Typography>
      </Paper>
      <h2>FAQ</h2>
      <Paper className={classes.paper}>
        <Typography variant="body1">
          <h4>What do I need to do before deploying an IOC with this system?</h4>
          <ul>
            <li>Have an IOC registered in CCDB.</li>
            <li>Have an intended host (virtual or physical) which is registered in CSEntry as an IOC host (checkbox during creation).</li>
            <li>Have an IOC repository with public visibility in the <span style={{ fontFamily: "monospace" }}>iocs</span> group on ESS Gitlab.</li>
          </ul>

          <h4>How do I deploy my IOC?</h4>
          You first have to register the IOC in the system, and then you go to deploy a specific version of that IOC to a specific target host.

          <h4>Why do I first need to register the IOC, and then deploy (as a separate step)?</h4>
          This deployment tool is only a part of the CCDB toolchain. Normally IOC Factory would create your IOC, but since this is a beta programme that focuses only on deployment, you have the option of deploying non-IOC Factory created IOCs.

          <h4>Why can I not see my IOC/host/repository in the dropdown list?</h4>
          The deployment tool will only show you valid options. To be able to import the IOC, it needs to exist as an IOC in CCDB. To see the host it needs to be registered as an IOC host in CSEntry prior to installing the operating system. And to be able to find your IOC repository, it needs to exist in the correct gitlab group (which you can find <Link href="https://gitlab.esss.lu.se/iocs" target="_blank" rel="noreferrer">here</Link>).

          <h4>What does the deployment system do? Is there something I need to be aware of?</h4>
          The deployment system will set up your host machine to run only the IOCs defined in this tool, and will configure all necessary services to do so. This means that it might interfer with other (already running) processes on the machine, which is part of why it is a requirement to start from blank (formatted) machines; another part of this requirement comes from some setup being done at the OS-installation stage.

          <h4>How do I migrate IOCs that have been deployed with another deployment system (e.g. CCCE alpha or LDS)?</h4>
          You make sure that the repositories are up to date and that the IOCs have been undeployed elsewhere.

          <h4>What does the yellow and red backgrounds mean?</h4>
          They mean that your IOC(s) have various issues that you need to address. Details on the specific warnings can be found for the IOC&apos;s own detail page.

          <h4>How do I transfer ownership of an IOC?</h4>
          You contact the CCCE team.

          <h4>I accidentally connected to the wrong CCDB IOC/the wrong git repository - what do I do?</h4>
          You contact the CCCE team.
        </Typography>
      </Paper>
    </RootContainer>
  )
}