import { Container, Grid, Hidden, Paper, Button, Box, Typography } from "@material-ui/core";
import React, { useContext, useState, useEffect } from "react";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { SearchableIOCList } from "../../components/IOC/IOCList";
import { CreateIOC } from "../../components/IOC/CreateIOC";
import { SearchableIOCTable } from "../../components/IOC/IOCTable";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { useCreateIOC, useIOCSearch, userContext } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";

const useStyles = makeStyles((theme) => ({
  root: {
    marginBottom: theme.spacing(2),
  },
}));

export function HomeView() {
  const [iocs, getIocs] = useIOCSearch();
  const [query, setQuery] = useState();
  const [iocFormOpen, setIOCFormOpen] = useState(false);
  const {user} = useContext(userContext);
  const classes = useStyles();

  console.log("rendering Own IOCs")

  const title = "Home";
  useGlobalAppBar(title);

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 20,
    page: 0
  });
  
  const [columnSort, setColumnSort] = useState({
    sortField: null,
    sortOrder: null
  });

  const rowsPerPage = [5, 10, 20, 50, 100];

  const closeModal = () => {
    setIOCFormOpen(false);
  }  


  useEffect(() => {
    let requestParams = initRequestParams(lazyParams, query, columnSort);

    requestParams.owner = user?.loginName;

    if(columnSort.sortField === "owner") {
      requestParams.orderBy = "OWNER";
    }

    if(columnSort.sortField === "namingName") {
      requestParams.orderBy = "IOC_NAME";
    }

    if(columnSort.sortField === "sourceVersion") {
      requestParams.orderBy = "GIT_REFERENCE";
    }

    getIocs(requestParams);
  }, [getIocs, user, lazyParams, query, columnSort])


  let content = (
      <>
      <Hidden smUp>
          <SearchableIOCList iocs={iocs.iocList} setQuery={setQuery}/>
      </Hidden>
      <Hidden xsDown>
          <SearchableIOCTable iocs={iocs.iocList} setQuery={setQuery} rowType="own" iocQuery={getIocs} searchFilter={query} queryType="ioc" searchForOwn={true}
            totalCount={iocs.totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort}
            rowsPerPage={rowsPerPage}/>
      </Hidden>
      </>
  );

  return (
    <Container>
      <Paper className={classes.root}>
          <Grid container spacing={1} justify="flex-end">
            <Grid item xs={10}>
              <Box display="flex" flexDirection="row" p={2} m={1}>
              <Typography variant="h2">
                My IOCs
              </Typography>
              </Box>
            </Grid>
            <Grid item xs={2}>
              <Box display="flex" flexDirection="row-reverse" p={2} m={1}>
                <Button variant="contained" color="secondary" onClick={() => { setIOCFormOpen(true) }}>New IOC</Button>
              </Box>
            </Grid>
            <Grid item xs={12}>
              {content}
            </Grid>
            <SimpleModal open={iocFormOpen} setOpen={setIOCFormOpen}>
              <CreateIOC open={iocFormOpen} setOpen={setIOCFormOpen} isUpdateIoc={false} submitCallback={closeModal} hook={useCreateIOC} title="Create new IOC" buttonText="Create"/>
            </SimpleModal>
          </Grid>
      </Paper>
    </Container>
  );
}

