import React, { useEffect } from "react";
import { Paper, Box } from "@material-ui/core";
import { KeyValueTable } from '../../components/common/KeyValueTable/KeyValueTable';
import { useStatistics } from "../../api/SwaggerApi";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { RootContainer } from "../../components/common/Container/RootContainer";
import ActiveIOCChart from "../../components/statistics/ActiveIOCChart";
import DeploymentLineChart from "../../components/statistics/DeploymentLineChart";
import { useActiveIOCHistory, useDeployedIOCStatistics } from '../../api/SwaggerApi';

const clone = (obj) => Object.assign({}, obj);

const renameKey = (object, key, newKey) => {

    const clonedObj = clone(object);
    const targetKey = clonedObj[key];

    delete clonedObj[key];
    clonedObj[newKey] = targetKey;

    return clonedObj;
};

export function StatisticsView() {

    const title = "Statistics";
    useGlobalAppBar(title);

    const [statistics, getStatistics] = useStatistics();

    useEffect(() =>
        getStatistics()
        , [getStatistics]
    );

    let renderStat = { ...statistics };

    //rename "response fields" into readable format
    if (statistics) {
        renderStat = renameKey(renderStat, "numberOfActiveIocs", " Number of active IOCs (Prometheus)");
        renderStat = renameKey(renderStat, "numberOfActiveHosts", " Number of active Hosts (Prometheus)");
        renderStat = renameKey(renderStat, "numberOfCreatedIocs", " Number of IOCs created (DB)");
        renderStat = renameKey(renderStat, "numberOfActiveDeployments", " Number of active deployments (DB)");
        renderStat = renameKey(renderStat, "numberOfDeployments", " Total number of deployments (DB)");
    }

    return (
        <RootContainer>
            <h2>Statistics</h2>
            <Paper>
                {statistics && <KeyValueTable obj={renderStat} variant="table" />}
            </Paper>
            
            <Box m={2} />

            <Paper>
                <DeploymentLineChart title="Number of successful deployments by the Deployment tool" chartLabel="Deployed IOCs in time" hook={useDeployedIOCStatistics}/>
            </Paper>
            
            <Box m={2} />
            
            <Paper>
                <ActiveIOCChart />
            </Paper>    

            <Box m={2} />

            <Paper>
                <DeploymentLineChart title="IOC deployment history graph (Prometheus)" chartLabel="Active IOCs in time" hook={useActiveIOCHistory}/>
            </Paper>

        </RootContainer>
    )
}